/*
 * Copyright (c) 2016 Couchbase, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.couchbase.client.core.message.search;

import com.couchbase.client.core.message.AbstractCouchbaseResponse;
import com.couchbase.client.core.message.ResponseStatus;

/**
 * Result of the full text search query.
 *
 * @author Sergey Avseyev
 * @since 1.2.4
 */
public class SearchQueryResponse extends AbstractCouchbaseResponse {

    private final String payload;
    private final int statusCode;

    public SearchQueryResponse(String payload, ResponseStatus status, int statusCode) {
        super(status, null);
        this.payload = payload;
        this.statusCode = statusCode;
    }

    public String payload() {
        return payload;
    }

    /**
     * Returns the raw http status code.
     */
    public int statusCode() {
        return statusCode;
    }

    @Override
    public String toString() {
        return "SearchQueryResponse{"
            + "status=" + status()
            + ", statusCode=" + statusCode()
            + ", payload='" + payload + '\''
            + '}';
    }
}
